package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseMaintStandard;
import com.hw.dms.service.IDmsBaseMaintStandardService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 保养标准信息Controller
 * 
 * @author xins
 * @date 2024-01-05
 */
@RestController
@RequestMapping("/standard")
public class DmsBaseMaintStandardController extends BaseController
{
    @Autowired
    private IDmsBaseMaintStandardService dmsBaseMaintStandardService;

    /**
     * 查询保养标准信息列表
     */
    @RequiresPermissions("dms:standard:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseMaintStandard dmsBaseMaintStandard)
    {
        startPage();
        List<DmsBaseMaintStandard> list = dmsBaseMaintStandardService.selectDmsBaseMaintStandardList(dmsBaseMaintStandard);
        return getDataTable(list);
    }

    /**
     * 导出保养标准信息列表
     */
    @RequiresPermissions("dms:standard:export")
    @Log(title = "保养标准信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseMaintStandard dmsBaseMaintStandard)
    {
        List<DmsBaseMaintStandard> list = dmsBaseMaintStandardService.selectDmsBaseMaintStandardList(dmsBaseMaintStandard);
        ExcelUtil<DmsBaseMaintStandard> util = new ExcelUtil<DmsBaseMaintStandard>(DmsBaseMaintStandard.class);
        util.exportExcel(response, list, "保养标准信息数据");
    }

    /**
     * 获取保养标准信息详细信息
     */
    @RequiresPermissions("dms:standard:query")
    @GetMapping(value = "/{maintStandardId}")
    public AjaxResult getInfo(@PathVariable("maintStandardId") Long maintStandardId)
    {
        return success(dmsBaseMaintStandardService.selectDmsBaseMaintStandardByMaintStandardId(maintStandardId));
    }

    /**
     * 新增保养标准信息
     */
    @RequiresPermissions("dms:standard:add")
    @Log(title = "保养标准信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseMaintStandard dmsBaseMaintStandard)
    {
        return toAjax(dmsBaseMaintStandardService.insertDmsBaseMaintStandard(dmsBaseMaintStandard));
    }

    /**
     * 修改保养标准信息
     */
    @RequiresPermissions("dms:standard:edit")
    @Log(title = "保养标准信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseMaintStandard dmsBaseMaintStandard)
    {
        return toAjax(dmsBaseMaintStandardService.updateDmsBaseMaintStandard(dmsBaseMaintStandard));
    }

    /**
     * 删除保养标准信息
     */
    @RequiresPermissions("dms:standard:remove")
    @Log(title = "保养标准信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{maintStandardIds}")
    public AjaxResult remove(@PathVariable Long[] maintStandardIds)
    {
        return toAjax(dmsBaseMaintStandardService.deleteDmsBaseMaintStandardByMaintStandardIds(maintStandardIds));
    }
}
